@@ -56,6 +56,8 @@ class ReadRequestBuildingBlocks:
     constraints: typing.List[typing.Any]
     effective_start_dt: datetime.datetime = None
     effective_end_dt: datetime.datetime = None
+    valid_start_dt: datetime.datetime = None
+    valid_end_dt: datetime.datetime = None
     knowledge_start_dt: datetime.datetime = None
     knowledge_end_dt: datetime.datetime = None
     query: typing.Any = None
@@ -91,6 +93,8 @@ class ReadRequest:
     effective_end_dt: datetime.datetime
     pointers: typing.Dict[str, str]
     columns: typing.List[str] = None
+    valid_start_dt: datetime.datetime = None
+    valid_end_dt: datetime.datetime = None
     knowledge_start_dt: datetime.datetime = None
     knowledge_end_dt: datetime.datetime = None
     query_builder: typing.Callable[
@@ -110,6 +114,8 @@ class ReadUniverseRequest:
     universe: Universe
     effective_start_dt: datetime.datetime
     effective_end_dt: datetime.datetime
+    valid_start_dt: datetime.datetime = None
+    valid_end_dt: datetime.datetime = None
     knowledge_start_dt: datetime.datetime = None
     knowledge_end_dt: datetime.datetime = None
 
