@@ -6,8 +6,18 @@ from timeit import default_timer as timer
 from bakplane.bakplane_pb2 import *
 from bakplane.bakplane_pb2_grpc import BakplaneStub
 from bakplane.errors import BakplaneException
-from bakplane.extensions.base import BaseExtension, PluginEntry, ReadRequest, ReadResponse, WriteRequest, WriteResponse, \
-    ReadUniverseRequest, ReadUniverseResponse, ReadAllRequest, ExecutionStatistics
+from bakplane.extensions.base import (
+    BaseExtension,
+    PluginEntry,
+    ReadRequest,
+    ReadResponse,
+    WriteRequest,
+    WriteResponse,
+    ReadUniverseRequest,
+    ReadUniverseResponse,
+    ReadAllRequest,
+    ExecutionStatistics,
+)
 from bakplane.extensions.spark.stores import redshift, postgres
 from bakplane.utils import to_proto_timestamp_range, parse_value_by_type
 
@@ -21,7 +31,7 @@ def register_plugin(entry):
 
 def get_plugin_or_die(code: str) -> PluginEntry:
     if code not in __plugins:
-        raise RuntimeError(f'Failed to obtain plugin `{code}`.')
+        raise RuntimeError(f"Failed to obtain plugin `{code}`.")
 
     return __plugins[code]
 
@@ -36,7 +46,9 @@ class SparkExtension(BaseExtension):
             intent = self.stub.ResolveResourceIntent(
                 ResolveResourceRequest(
                     universe=r.universe,
-                    effective_dating=to_proto_timestamp_range(r.effective_start_dt, r.effective_end_dt),
+                    effective_dating=to_proto_timestamp_range(
+                        r.effective_start_dt, r.effective_end_dt
+                    ),
                     path=r.path,
                     warehouse=r.warehouse,
                     pointers=r.pointers,
@@ -44,62 +56,68 @@ class SparkExtension(BaseExtension):
             )
 
             if not intent:
-                raise RuntimeError('Failed to resolve intent.')
+                raise RuntimeError("Failed to resolve intent.")
 
             p = get_plugin_or_die(intent.warehouse_kind)
             return p.read_fn(self.spark, r, intent)
         except Exception as ex:
-            raise BakplaneException('Failed to execute read request.', ex)
+            raise BakplaneException("Failed to execute read request.", ex)
 
     def write(self, r: WriteRequest) -> WriteResponse:
         try:
-            logging.info(f'Writing to resource path `{r.path}`.')
+            logging.info(f"Writing to resource path `{r.path}`.")
 
             internals = self.stub.ResolveResourcePath(
                 ResolveResourcePathRequest(path=r.path, warehouse=r.warehouse)
             )
 
             if not internals:
-                raise RuntimeError('Failed to resolve resource path.')
+                raise RuntimeError("Failed to resolve resource path.")
 
             p = get_plugin_or_die(internals.warehouse_kind)
             return p.write_fn(r, internals)
         except Exception as ex:
-            raise BakplaneException('Failed to execute write request.', ex)
+            raise BakplaneException("Failed to execute write request.", ex)
 
     def read_universe(self, r: ReadUniverseRequest) -> ReadUniverseResponse:
         try:
-            logging.info(f'Resolving universe `{r}`.')
+            logging.info(f"Resolving universe `{r}`.")
 
-            res = self.stub.ResolveUniverse(ResolveUniverseRequest(
-                universe=r.universe,
-                effective_dating=to_proto_timestamp_range(r.effective_start_dt, r.effective_end_dt)
-            ))
+            res = self.stub.ResolveUniverse(
+                ResolveUniverseRequest(
+                    universe=r.universe,
+                    effective_dating=to_proto_timestamp_range(
+                        r.effective_start_dt, r.effective_end_dt
+                    ),
+                )
+            )
 
             if not res:
-                raise RuntimeError('Failed to resolve universe.')
+                raise RuntimeError("Failed to resolve universe.")
             return self.__build_read_universe_response(res)
 
         except Exception as ex:
-            raise BakplaneException('Failed to read universe.', ex)
+            raise BakplaneException("Failed to read universe.", ex)
 
     def read_all(self, r: ReadAllRequest) -> ReadResponse:
         try:
-            logging.info(f'Resolving resource path `{r.path}`.')
+            logging.info(f"Resolving resource path `{r.path}`.")
 
             res = self.stub.ResolveResourcePath(
                 ResolveResourcePathRequest(path=r.path, warehouse=r.warehouse)
             )
 
             if not res:
-                raise RuntimeError('Failed to resolve resource path.')
+                raise RuntimeError("Failed to resolve resource path.")
 
             p = get_plugin_or_die(res.warehouse_kind)
             return p.read_all_fn(self.spark, r, res)
         except Exception as ex:
-            raise BakplaneException('Failed to execute read all request.', ex)
+            raise BakplaneException("Failed to execute read all request.", ex)
 
-    def __build_read_universe_response(self, res: typing.Iterable[ResolveUniverseGroupEntry]) -> ReadUniverseResponse:
+    def __build_read_universe_response(
+        self, res: typing.Iterable[ResolveUniverseGroupEntry]
+    ) -> ReadUniverseResponse:
         start = timer()
 
         rows = []
@@ -120,9 +138,7 @@ class SparkExtension(BaseExtension):
 
         return ReadUniverseResponse(
             df=self.spark.createDataFrame(data=rows, schema=schema),
-            execution_statistics=ExecutionStatistics(
-                elapsed_ms=(end - start)
-            )
+            execution_statistics=ExecutionStatistics(elapsed_ms=(end - start)),
         )
 
 
