@@ -198,7 +198,7 @@ def create_table_if_needed(
         columns.append(
             Column(
                 c["name"],
-                map_attribute_type(c["type"], c),
+                map_attribute_type(c["data_type"], c),
                 nullable="mode" in c and c["mode"] == "nullable",
             )
         )
@@ -223,6 +223,7 @@ def create_table_if_needed(
             "knowledge_end_dt",
             "effective_start_dt",
             "valid_start_dt",
+            "valid_end_dt",
         ),
         schema=schema,
     )
@@ -402,7 +403,7 @@ def generate_initial_migrations(
 @click.option(
     "--bucket",
     "-b",
-    default="bakplane-dev-migrations",
+    default="bakplane-dev-migrations-internal",
     required=True,
     help="The bucket containing the migrations.",
 )
